@@ -2,7 +2,7 @@
 # extension modules created with SIP.  It provides information about file
 # locations, version numbers etc., and provides some classes and functions.
 #
-# Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -26,25 +26,23 @@ import re
 
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
-    'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/bin',
-    'default_mod_dir':    '/usr/lib/python3.10/site-packages',
+    'default_mod_dir':    '/usr/lib/python3.5/site-packages',
     'default_sip_dir':    '/usr/share/sip',
     'deployment_target':  '',
     'platform':           'linux-g++',
-    'py_conf_inc_dir':    '/usr/include/python3.10',
-    'py_inc_dir':         '/usr/include/python3.10',
-    'py_lib_dir':         '/usr/lib/python3.10/config',
-    'py_version':         0x030a01,
+    'py_conf_inc_dir':    '/usr/include/python3.5m',
+    'py_inc_dir':         '/usr/include/python3.5m',
+    'py_lib_dir':         '/usr/lib/python3.5/config',
+    'py_version':         0x030500,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
-    'sip_inc_dir':        '/usr/include/python3.10',
-    'sip_module_dir':     '/usr/lib/python3.10/site-packages',
-    'sip_root_dir':       '/usr/lib/python3.10/site-packages',
-    'sip_version':        0x041319,
-    'sip_version_str':    '4.19.25',
+    'sip_config_args':    'CFLAGS=-march=armv8-a -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'sip_inc_dir':        '/usr/include/python3.5m',
+    'sip_mod_dir':        '/usr/lib/python3.5/site-packages',
+    'sip_version':        0x041009,
+    'sip_version_str':    '4.16.9',
     'universal':          ''
 }
 
@@ -52,7 +50,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt',
+    'CFLAGS':                   '-march=armv8-a -O2 -pipe -fstack-protector --param=ssp-buffer-size=4',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -101,7 +99,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
@@ -337,8 +335,7 @@ class Makefile:
         installs is a list of extra install targets.  Each element is a two
         part list, the first of which is the source and the second is the
         destination.  If the source is another list then it is a set of source
-        files and the destination is a directory.  If the destination is None
-        then the source is a command to run.
+        files and the destination is a directory.
         universal is the name of the SDK if the target is a MacOS/X universal
         binary.  If it is None then the value is taken from the configuration.
         arch is the space separated MacOS/X architectures to build.  If it is
@@ -1258,10 +1255,7 @@ class Makefile:
                 self._installs = [self._installs]
 
             for src, dst in self._installs:
-                if dst is None:
-                    mfile.write("\t%s\n" % src)
-                else:
-                    self.install_file(mfile, src, dst)
+                self.install_file(mfile, src, dst)
 
         self.generate_target_clean(mfile)
 
